pub struct Json;Trait Implementations
Sourceimpl DataFormat for Json
impl DataFormat for Json
Sourcetype Output = String
type Output = String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_null(&self) -> String
fn format_null(&self) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_bool(&self, v: &bool) -> String
fn format_bool(&self, v: &bool) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_string(&self, v: &str) -> String
fn format_string(&self, v: &str) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_i64(&self, v: &i64) -> String
fn format_i64(&self, v: &i64) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_f64(&self, v: &f64) -> String
fn format_f64(&self, v: &f64) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_ip(&self, v: &IpAddr) -> String
fn format_ip(&self, v: &IpAddr) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_datetime(&self, v: &NaiveDateTime) -> String
fn format_datetime(&self, v: &NaiveDateTime) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_object(&self, v: &ObjectValue) -> String
fn format_object(&self, v: &ObjectValue) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_array(&self, v: &[FieldStorage]) -> String
fn format_array(&self, v: &[FieldStorage]) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_field(&self, f: &FieldStorage) -> String
fn format_field(&self, f: &FieldStorage) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourcefn format_record(&self, r: &DataRecord) -> String
fn format_record(&self, r: &DataRecord) -> String
👎Deprecated since 0.2.0: Use ValueFormatter and RecordFormatter instead. This trait will be removed in the next major version.
Sourceimpl StaticDataFormatter for Json
impl StaticDataFormatter for Json
Sourcetype Output = String
type Output = String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_null() -> String
fn stdfmt_null() -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_bool(value: &bool) -> String
fn stdfmt_bool(value: &bool) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_string(value: &str) -> String
fn stdfmt_string(value: &str) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_i64(value: &i64) -> String
fn stdfmt_i64(value: &i64) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_f64(value: &f64) -> String
fn stdfmt_f64(value: &f64) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_ip_addr(value: &IpAddr) -> String
fn stdfmt_ip_addr(value: &IpAddr) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_datetime(value: &NaiveDateTime) -> String
fn stdfmt_datetime(value: &NaiveDateTime) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_object(value: &ObjectValue) -> String
fn stdfmt_object(value: &ObjectValue) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_array(value: &[FieldStorage]) -> String
fn stdfmt_array(value: &[FieldStorage]) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_field(field: &FieldStorage) -> String
fn stdfmt_field(field: &FieldStorage) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_record(record: &DataRecord) -> String
fn stdfmt_record(record: &DataRecord) -> String
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourcefn stdfmt_value(value: &Value) -> Self::Output
fn stdfmt_value(value: &Value) -> Self::Output
👎Deprecated since 0.2.0: Use ValueFormatter instead with instance methods. This trait will be removed in the next major version.
Sourceimpl RecordFormatter for Json
impl RecordFormatter for Json
Sourcefn fmt_record(&self, record: &DataRecord) -> String
fn fmt_record(&self, record: &DataRecord) -> String
格式化整条记录 Read more